// Copyright 2022-latest Tomoki Miyauchi. All rights reserved. MIT license.
// This module is browser compatible.
/** Whether the value is odd or not.
 * @param value - Any `number`.
 * @example
 * ```ts
 * import { isOdd } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isOdd(1), true)
 * assertEquals(isOdd(0), false)
 * ```
 */
export function isOdd(value) {
    return Math.abs(value) % 2 === 1;
}
/** Whether the value is even or not.
 * @param value - Any `number`.
 * @example
 * ```ts
 * import { isEven } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isEven(0), true)
 * assertEquals(isEven(1), false)
 * ```
 */
export function isEven(value) {
    return Math.abs(value) % 2 === 0;
}
/** Whether the value is positive number or not.
 * @param value - Any `number`.
 * @example
 * ```ts
 * import { isPositiveNumber } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isPositiveNumber(1), true)
 * assertEquals(isPositiveNumber(0), false)
 * ```
 */
export function isPositiveNumber(value) {
    return Number.isFinite(value) && value > 0;
}
/** Whether the input is non-positive number or not.
 * Non-positive number means less than or equal to zero.
 * @param value - Any `number`.
 * @example
 * ```ts
 * import { isNonPositiveNumber } from "https://deno.land/x/isx@$VERSION/mod.ts";
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts";
 * assertEquals(isNonPositiveNumber(0), true);
 * assertEquals(isNonPositiveNumber(-1), true);
 * assertEquals(isNonPositiveNumber(1), false);
 * ```
 */
export function isNonPositiveNumber(value) {
    return Number.isFinite(value) && value <= 0;
}
/** Whether the value is negative number or not.
 * @param value - Any `number`.
 * @example
 * ```ts
 * import { isNegativeNumber } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isNegativeNumber(-1), true)
 * assertEquals(isNegativeNumber(0), false)
 * ```
 */
export function isNegativeNumber(value) {
    return Number.isFinite(value) && value < 0;
}
/** Whether the input is non-negative number or not.
 * Non-negative number means greater than or equal to zero.
 * @param value - Any `number`.
 * @example
 * ```ts
 * import { isNonNegativeNumber } from "https://deno.land/x/isx@$VERSION/mod.ts";
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts";
 * assertEquals(isNonNegativeNumber(0), true);
 * assertEquals(isNonNegativeNumber(1), true);
 * assertEquals(isNonNegativeNumber(-1), false);
 * ```
 */
export function isNonNegativeNumber(value) {
    return Number.isFinite(value) && 0 <= value;
}
/** Whether the value is non negative integer or not.
 * @param value - Any `number`.
 * @example
 * ```ts
 * import { isNonNegativeInteger } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isNonNegativeInteger(0), true)
 * assertEquals(isNonNegativeInteger(1.0), true)
 * assertEquals(isNonNegativeInteger(-1), false)
 * ```
 */
export function isNonNegativeInteger(value) {
    return Number.isInteger(value) && value >= 0;
}
