"use strict";
// Copyright 2022-latest Tomoki Miyauchi. All rights reserved. MIT license.
// This module is browser compatible.
Object.defineProperty(exports, "__esModule", { value: true });
exports.isEmptyObject = exports.isRegExp = exports.isTruthy = exports.isFalsy = exports.isAsyncIterable = exports.isPromise = exports.isPrimitive = exports.isError = exports.isIterable = exports.isDate = exports.isSymbol = exports.isObject = exports.isFunction = exports.isNonNullable = exports.isNullable = exports.isBoolean = exports.isFalse = exports.isTrue = exports.isUndefined = exports.isNull = exports.isBigint = exports.isNumber = exports.isString = void 0;
/** Whether the value is `string` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isString } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isString('hello world'), true)
 * assertEquals(isString(1000), false)
 * ```
 */
function isString(value) {
    return typeof value === "string";
}
exports.isString = isString;
/** Whether the value is `number` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isNumber } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isNumber(1000), true)
 * assertEquals(isNumber('hello world'), false)
 * ```
 */
function isNumber(value) {
    return typeof value === "number";
}
exports.isNumber = isNumber;
/** Whether the value is `bigint` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isBigint } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isBigint(1000n), true)
 * assertEquals(isBigint(undefined), false)
 * ```
 */
function isBigint(value) {
    return typeof value === "bigint";
}
exports.isBigint = isBigint;
/** Whether the value is `null` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isNull } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isNull(null), true)
 * assertEquals(isNull(undefined), false)
 * ```
 */
function isNull(value) {
    return value === null;
}
exports.isNull = isNull;
/** Whether the value is `undefined` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isUndefined } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isUndefined(undefined), true)
 * assertEquals(isUndefined(null), false)
 * ```
 */
function isUndefined(value) {
    return typeof value === "undefined";
}
exports.isUndefined = isUndefined;
/** Whether the value is `true` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isTrue } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isTrue(true), true)
 * assertEquals(isTrue(false), false)
 * ```
 */
function isTrue(value) {
    return value === true;
}
exports.isTrue = isTrue;
/** Whether the value is `false` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isFalse } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isFalse(false), true)
 * assertEquals(isFalse(true), false)
 * ```
 */
function isFalse(value) {
    return value === false;
}
exports.isFalse = isFalse;
/** Whether the value is `boolean` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isBoolean } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isBoolean(true), true)
 * assertEquals(isBoolean(null), false)
 * ```
 */
function isBoolean(value) {
    return typeof value === "boolean";
}
exports.isBoolean = isBoolean;
/** Whether the value is `null` or `undefined` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isNullable } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isNullable(null), true)
 * assertEquals(isNullable(undefined), true)
 * assertEquals(isNullable({}), false)
 * ```
 */
function isNullable(value) {
    return isNull(value) || isUndefined(value);
}
exports.isNullable = isNullable;
/** Whether the value is non-nullable or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isNonNullable } from "https://deno.land/x/isx@$VERSION/mod.ts";
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts";
 * assertEquals(isNonNullable({}), true);
 * assertEquals(isNonNullable(null), false);
 * assertEquals(isNonNullable(undefined), false);
 * ```
 */
function isNonNullable(value) {
    return !isNullable(value);
}
exports.isNonNullable = isNonNullable;
/** Whether the value is `Function` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isFunction } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isFunction(() => {}), true)
 * assertEquals(isFunction({}), false)
 * ```
 */
function isFunction(value) {
    return typeof value === "function";
}
exports.isFunction = isFunction;
/** Whether the value is `object` or not.
 * @param value - Any value.
 *
 * ```ts
 * import { isObject } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isObject({}), true)
 * assertEquals(isObject(null), false)
 * ```
 */
function isObject(value) {
    return typeof value === "object" && !isNull(value);
}
exports.isObject = isObject;
/** Whether the value is `symbol` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isSymbol } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isSymbol(Symbol("symbol")), true)
 * assertEquals(isSymbol(null), false)
 * ```
 */
function isSymbol(value) {
    return typeof value === "symbol";
}
exports.isSymbol = isSymbol;
/** Whether the value is `Date` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isDate } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isDate(new Date()), true)
 * assertEquals(isDate({}), false)
 * ```
 */
function isDate(value) {
    return value instanceof Date;
}
exports.isDate = isDate;
/** Whether the value is `Iterable` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isIterable } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isIterable(""), true)
 * assertEquals(isIterable({}), false)
 * ```
 */
function isIterable(value) {
    return isFunction(Object(value)[Symbol.iterator]);
}
exports.isIterable = isIterable;
/** Whether the value is `Error` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isError } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isError(Error()), true)
 * assertEquals(isError(new SyntaxError()), true)
 * assertEquals(isError(new Date()), false);
 * ```
 */
function isError(value) {
    return value instanceof Error;
}
exports.isError = isError;
/** Whether the value is {@link Primitive} or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isPrimitive } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isPrimitive(true), true)
 * assertEquals(isPrimitive(() => {}), false)
 * ```
 */
function isPrimitive(value) {
    return !isObject(value) && !isFunction(value);
}
exports.isPrimitive = isPrimitive;
/** Whether the value is `Promise` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isPromise } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isPromise(Promise.resolve()), true)
 * assertEquals(isPromise({}), false)
 * ```
 */
function isPromise(value) {
    return value instanceof Promise;
}
exports.isPromise = isPromise;
/** Whether the value is `AsyncIterable` or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isAsyncIterable } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(
 *   isAsyncIterable({
 *     async *[Symbol.asyncIterator]() {
 *       yield "hello";
 *     },
 *   }),
 *   true,
 * );
 * assertEquals(isAsyncIterable(() => {}), false);
 * ```
 */
function isAsyncIterable(value) {
    return isFunction(Object(value)[Symbol.asyncIterator]);
}
exports.isAsyncIterable = isAsyncIterable;
/** Whether the value is {@link FalsyLike} or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isFalsy } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isFalsy(0), true)
 * assertEquals(isFalsy(""), true)
 * assertEquals(isFalsy("a"), false)
 * ```
 */
function isFalsy(value) {
    return !value;
}
exports.isFalsy = isFalsy;
/** Whether the value is {@link TruthyLike} or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isTruthy } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isTruthy(1), true)
 * assertEquals(isTruthy("a"), true)
 * assertEquals(isTruthy(0), false)
 * ```
 */
function isTruthy(value) {
    return !!value;
}
exports.isTruthy = isTruthy;
/** Whether the value is `RegExp` of not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isRegExp } from "https://deno.land/x/isx@$VERSION/mod.ts";
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts";
 * assertEquals(isRegExp(new RegExp("")), true);
 * assertEquals(isRegExp({}), false);
 * ```
 */
function isRegExp(value) {
    return value instanceof RegExp;
}
exports.isRegExp = isRegExp;
/** Whether the value is empty object or not.
 * @param value - Any value.
 * @example
 * ```ts
 * import { isEmptyObject } from "https://deno.land/x/isx@$VERSION/mod.ts";
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts";
 * assertEquals(isEmptyObject({}), true);
 * assertEquals(isEmptyObject({ a: "b" }), false);
 * assertEquals(isEmptyObject([]), false);
 * ```
 */
function isEmptyObject(value) {
    return !Object.getOwnPropertyNames(value).length &&
        !Object.getOwnPropertySymbols(value).length;
}
exports.isEmptyObject = isEmptyObject;
