/** Whether the value is Hex color or not.
 * @param value - Any `string`.
 * @example
 * ```ts
 * import { isHexColorFormat } from "https://deno.land/x/isx@$VERSION/mod.ts"
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts"
 * assertEquals(isHexColorFormat("#000000"), true)
 * assertEquals(isHexColorFormat("#FFF"), true)
 * assertEquals(isHexColorFormat("#ggg"), false)
 * ```
 */
export declare function isHexColorFormat(value: string): boolean;
/** Whether the value is hostname format or not.
 * @param value - Any `string`.
 * @example
 * ```ts
 * import { isHostnameFormat } from "https://deno.land/x/isx@$VERSION/mod.ts";
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts";
 * assertEquals(isHostnameFormat("a"), true);
 * assertEquals(isHostnameFormat("test.test"), true);
 * assertEquals(isHostnameFormat("."), false);
 * ```
 */
export declare function isHostnameFormat(value: string): boolean;
type TimeHour = string;
type TimeMinute = string;
type TimeSecond = string;
type TimeNumoffset = `${"+" | "-"}${TimeHour}:${TimeMinute}`;
type TimeOffset = "Z" | TimeNumoffset;
type PartialType = `${TimeHour}:${TimeMinute}:${TimeSecond}`;
type DateFullyear = string;
type DateMonth = string;
type DateMday = string;
/** Types for date format. */
export type DateFormat = `${DateFullyear}-${DateMonth}-${DateMday}`;
/** Types for time format. */
export type TimeFormat = `${PartialType}${TimeOffset}`;
/** Types for date time format. */
export type DateTimeFormat = `${DateFormat}T${TimeFormat}`;
/** Whether the value is RFC 3339 date format or not.
 * The format compliant with {@link https://www.rfc-editor.org/rfc/rfc3339#section-5.6 RFC 3339, 5.6. Internet Date/Time Format, full-date}
 * @param value - Any `string`.
 * @example
 * ```ts
 * import { isRfc3339DateFormat } from "https://deno.land/x/isx@$VERSION/mod.ts";
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts";
 * assertEquals(isRfc3339DateFormat("0000-01-01"), true);
 * assertEquals(isRfc3339DateFormat("0000-00-00"), false);
 * ```
 */
export declare function isRfc3339DateFormat(value: string): value is DateFormat;
/** Whether the value is RFC 3339 time format or not.
 * The format compliant with {@link https://www.rfc-editor.org/rfc/rfc3339#section-5.6 RFC 3339, 5.6. Internet Date/Time Format, full-time}
 * @param value - Any `string`.
 * @example
 * ```ts
 * import { isRfc3339TimeFormat } from "https://deno.land/x/isx@$VERSION/mod.ts";
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts";
 * assertEquals(isRfc3339TimeFormat("00:00:00+00:00"), true);
 * assertEquals(isRfc3339TimeFormat("23:59:59Z"), true);
 * assertEquals(isRfc3339TimeFormat("24:00:00Z"), false);
 * ```
 */
export declare function isRfc3339TimeFormat(value: string): value is TimeFormat;
/** Whether the value is RFC 3339 date time format or not.
 * The format compliant with {@link https://www.rfc-editor.org/rfc/rfc3339#section-5.6 RFC 3339, 5.6. Internet Date/Time Format, date-time}
 * @param value - Any `string`.
 * @example
 * ```ts
 * import { isRfc3339DateTimeFormat } from "https://deno.land/x/isx@$VERSION/mod.ts";
 * import { assertEquals } from "https://deno.land/std@$VERSION/testing/asserts.ts";
 * assertEquals(isRfc3339DateTimeFormat("0001-01-01T00:00:00Z"), true);
 * assertEquals(isRfc3339DateTimeFormat("9999-12-31T23:59:59+19:59"), true);
 * assertEquals(isRfc3339DateTimeFormat("0000-00-00T00:00:00Z"), false);
 * ```
 */
export declare function isRfc3339DateTimeFormat(value: string): value is DateTimeFormat;
export {};
